@@ -1,7 +1,9 @@
+/* $Id: indep.h,v 1.7 2001/11/27 18:29:24 ukai Exp $ */
 #ifndef INDEP_H
 #define INDEP_H
 #include "gc.h"
 #include "Str.h"
+#include "config.h"
 
 #ifndef TRUE
 #define TRUE 1
@@ -22,7 +24,9 @@ extern int strCmp(const void *s1, const void *s2);
 extern char *currentdir(void);
 extern char *cleanupName(char *name);
 extern char *expandPath(char *name);
-extern char *strcasestr(char *s1, char *s2);
+#ifndef HAVE_STRCASESTR
+extern char *strcasestr(const char *s1, const char *s2);
+#endif
 extern int strcasemstr(char *str, char *srch[], char **ret_ptr);
 extern char *remove_space(char *str);
 extern int non_null(char *s);
@@ -38,6 +42,10 @@ extern Str Str_form_quote(Str x);
 extern Str Str_form_unquote(Str x);
 extern char *shell_quote(char *str);
 
+extern char *w3m_lib_dir();
+extern char *w3m_etc_dir();
+extern char *w3m_help_dir();
+
 #define New(type)	((type*)GC_MALLOC(sizeof(type)))
 #define NewAtom(type)	((type*)GC_MALLOC_ATOMIC(sizeof(type)))
 #define New_N(type,n)	((type*)GC_MALLOC((n)*sizeof(type)))
