@@ -1,3 +1,4 @@
+/* $Id: myctype.h,v 1.4 2001/12/10 15:23:08 ukai Exp $ */
 #ifndef _MYCTYPE_H
 #define _MYCTYPE_H
 
@@ -6,9 +7,12 @@
 #define MYCTYPE_ALPHA 4
 #define MYCTYPE_DIGIT 8
 #define MYCTYPE_PRINT 16
+#define MYCTYPE_HEX   32
 #define MYCTYPE_ALNUM (MYCTYPE_ALPHA|MYCTYPE_DIGIT)
+#define MYCTYPE_XDIGIT (MYCTYPE_HEX|MYCTYPE_DIGIT)
 
 #define GET_MYCTYPE(x) (MYCTYPE_MAP[(int)(unsigned char)(x)])
+#define GET_MYCDIGIT(x) (MYCTYPE_DIGITMAP[(int)(unsigned char)(x)])
 
 #define IS_CNTRL(x) (GET_MYCTYPE(x) & MYCTYPE_CNTRL)
 #define IS_SPACE(x) (GET_MYCTYPE(x) & MYCTYPE_SPACE)
@@ -16,8 +20,10 @@
 #define IS_DIGIT(x) (GET_MYCTYPE(x) & MYCTYPE_DIGIT)
 #define IS_PRINT(x) (GET_MYCTYPE(x) & MYCTYPE_PRINT)
 #define IS_ALNUM(x) (GET_MYCTYPE(x) & MYCTYPE_ALNUM)
+#define IS_XDIGIT(x) (GET_MYCTYPE(x) & MYCTYPE_XDIGIT)
 
 extern unsigned char MYCTYPE_MAP[];
+extern unsigned char MYCTYPE_DIGITMAP[];
 
 
 #define INTCTYPE_ASCII   1
