@@ -1,3 +1,4 @@
+/* $Id: w3mbookmark.c,v 1.5 2001/11/24 02:01:26 ukai Exp $ */
 #ifdef __EMX__
 #include <stdlib.h>
 #endif
@@ -12,17 +13,12 @@
 
 #if LANG == JA
 static char *bkmark_src1 = "<html><head><title>Bookmark Registration</title>\n\
-<body><h1>֥åޡϿ</h1>\n\n"
-#ifdef __EMX__
-"<form method=get action=\"file://%s/w3mbookmark.exe\">\n\n"
-#else
-"<form method=get action=\"file://%s/w3mbookmark\">\n\n"
-#endif
-"<input type=hidden name=mode value=register>\n\
+<body><h1>֥åޡϿ</h1>\n\n" "<form method=get action=\"file://%s/" W3MBOOKMARK_CMDNAME "\">\n\n" "<input type=hidden name=mode value=register>\n\
 <input type=hidden name=bmark value=\"%s\">\n\
 <table cellpadding=0>\n";
 
-static char *bkmark_src2 = "<tr><td>New Section:</td><td><input type=text name=newsection width=60></td></tr>\n\
+static char *bkmark_src2 =
+    "<tr><td>New Section:</td><td><input type=text name=newsection width=60></td></tr>\n\
 <tr><td>URL:</td><td><input type=text name=url value=\"%s\" width=60></td></tr>\n\
 <tr><td>Title:</td><td><input type=text name=title value=\"%s\" width=60></td></tr>\n\
 <tr><td><input type=submit name=submit value=\"Ͽ\"></td>\n\
@@ -33,17 +29,12 @@ static char *bkmark_src2 = "<tr><td>New Section:</td><td><input type=text name=n
 static char *default_section = "̤ʬ";
 #else				/* LANG != JA */
 static char *bkmark_src1 = "<html><head><title>Bookmark Registration</title>\n\
-<body><h1>Register to my bookmark</h1>\n\n"
-#ifdef __EMX__
-"<form method=get action=\"file://%s/w3mbookmark.exe\">\n\n"
-#else
-"<form method=get action=\"file://%s/w3mbookmark\">\n\n"
-#endif
-"<input type=hidden name=mode value=register>\n\
+<body><h1>Register to my bookmark</h1>\n\n" "<form method=get action=\"file://%s/" W3MBOOKMARK_CMDNAME "\">\n\n" "<input type=hidden name=mode value=register>\n\
 <input type=hidden name=bmark value=\"%s\">\n\
 <table cellpadding=0>\n";
 
-static char *bkmark_src2 = "<tr><td>New Section:</td><td><input type=text name=newsection width=60></td></tr>\n\
+static char *bkmark_src2 =
+    "<tr><td>New Section:</td><td><input type=text name=newsection width=60></td></tr>\n\
 <tr><td>URL:</td><td><input type=text name=url value=\"%s\" width=60></td></tr>\n\
 <tr><td>Title:</td><td><input type=text name=title value=\"%s\" width=60></td></tr>\n\
 <tr><td><input type=submit name=submit value=\"ADD\"></td>\n\
@@ -57,21 +48,11 @@ static char *default_section = "Miscellaneous";
 #define FALSE 0
 #define T   1
 
-static char end_section[] = "<!--End of section (do not delete this comment)-->\n";
+static char end_section[] =
+    "<!--End of section (do not delete this comment)-->\n";
 
 char *Local_cookie;
 
-#ifdef __EMX__
-static char *
-lib_dir()
-{
-    char *value = getenv("W3M_LIB_DIR");
-    return value ? value : LIB_DIR;
-}
-#else
-#define lib_dir() LIB_DIR
-#endif
-
 void
 print_bookmark_panel(char *bmark, char *url, char *title)
 {
@@ -80,32 +61,34 @@ print_bookmark_panel(char *bmark, char *url, char *title)
     char *p;
 
     printf("Content-Type: text/html\n\n");
-    printf(bkmark_src1, lib_dir(), bmark);
+    printf(bkmark_src1, w3m_lib_dir(), bmark);
     if ((f = fopen(bmark, "r")) != NULL) {
 	printf("<tr><td>Section:<td><select name=\"section\">\n");
 	while (tmp = Strfgets(f), tmp->length > 0) {
-           Strremovefirstspaces(tmp);
+	    Strremovefirstspaces(tmp);
 	    if (Strncasecmp_charp(tmp, "<h2>", 4) == 0) {
 		p = tmp->ptr + 4;
 		tmp2 = Strnew();
 		while (*p && *p != '<')
 		    Strcat_char(tmp2, *p++);
-		printf("<option value=\"%s\">%s</option>", tmp2->ptr, tmp2->ptr);
+		printf("<option value=\"%s\">%s</option>", tmp2->ptr,
+		       tmp2->ptr);
 	    }
 	}
 	printf("</select>\n");
     }
-    printf(bkmark_src2, html_quote(url), html_quote(title),Local_cookie);
+    printf(bkmark_src2, html_quote(url), html_quote(title), Local_cookie);
 }
 
 /* create new bookmark */
 static int
-create_new_bookmark(char *bmark, char *section, char *title, char *url, char *mode)
+create_new_bookmark(char *bmark, char *section, char *title, char *url,
+		    char *mode)
 {
     FILE *f;
     f = fopen(bmark, mode);
     if (f == NULL) {
-	printf("\nCan't open bookmark %s\n",bmark);
+	printf("\nCan't open bookmark %s\n", bmark);
 	return FALSE;
     }
     else {
@@ -136,10 +119,9 @@ insert_bookmark(char *bmark, struct parsed_tagarg *data)
     if (section == NULL || *section == '\0')
 	section = tag_get_value(data, "section");
     if (section == NULL || *section == '\0')
-        section = default_section;
+	section = default_section;
 
-    if (url == NULL || *url == '\0' ||
-	title == NULL || *title == '\0') {
+    if (url == NULL || *url == '\0' || title == NULL || *title == '\0') {
 	/* Bookmark not added */
 	return FALSE;
     }
@@ -149,7 +131,7 @@ insert_bookmark(char *bmark, struct parsed_tagarg *data)
 
     f = fopen(bmark, "r");
     if (f == NULL)
-	return create_new_bookmark(bmark,section,title,url,"w");
+	return create_new_bookmark(bmark, section, title, url, "w");
 
     section_tmp = Sprintf("<h2>%s</h2>\n", section);
     for (;;) {
@@ -158,19 +140,22 @@ insert_bookmark(char *bmark, struct parsed_tagarg *data)
 	    break;
 	if (Strcasecmp(tmp, section_tmp) == 0)
 	    section_found = 1;
-       if (section_found && !bmark_added) {
-           Strremovefirstspaces(tmp);
-           if (Strcmp_charp(tmp, end_section) == 0) {
-        pushText(tl, Sprintf("<li><a href=\"%s\">%s</a>\n", url, title)->ptr);
-        bmark_added = 1;
-           }
+	if (section_found && !bmark_added) {
+	    Strremovefirstspaces(tmp);
+	    if (Strcmp_charp(tmp, end_section) == 0) {
+		pushText(tl,
+			 Sprintf("<li><a href=\"%s\">%s</a>\n", url,
+				 title)->ptr);
+		bmark_added = 1;
+	    }
 	}
 	if (!bmark_added && Strcasecmp_charp(tmp, "</body>\n") == 0) {
 	    pushText(tl, Sprintf("<h2>%s</h2>\n<ul>\n", section)->ptr);
-	    pushText(tl, Sprintf("<li><a href=\"%s\">%s</a>\n", url, title)->ptr);
+	    pushText(tl,
+		     Sprintf("<li><a href=\"%s\">%s</a>\n", url, title)->ptr);
 	    pushText(tl, end_section);
 	    pushText(tl, "</ul>\n");
-           bmark_added = 1;
+	    bmark_added = 1;
 	}
 	pushText(tl, tmp->ptr);
     }
@@ -178,7 +163,7 @@ insert_bookmark(char *bmark, struct parsed_tagarg *data)
     if (!bmark_added) {
 	/* Bookmark not added; perhaps the bookmark file is ill-formed */
 	/* In this case, a new bookmark is appeneded after the bookmark file */
-	return create_new_bookmark(bmark,section,title,url,"a");
+	return create_new_bookmark(bmark, section, title, url, "a");
     }
     f = fopen(bmark, "w");
     while (tl->nitem) {
@@ -214,11 +199,11 @@ MAIN(int argc, char *argv[], char **envp)
     if (bmark == NULL || url == NULL) {
 	/* incomplete request */
 	printf("Content-Type: text/plain\n\n");
-	printf("Incomplete Request: QUERY_STRING=%s\n",qs);
+	printf("Incomplete Request: QUERY_STRING=%s\n", qs);
 	exit(1);
     }
     Local_cookie = getenv("LOCAL_COOKIE");
-    sent_cookie = tag_get_value(cgiarg,"cookie");
+    sent_cookie = tag_get_value(cgiarg, "cookie");
     if (Local_cookie == NULL) {
 	/* Local cookie not provided: maybe illegal invocation */
 	Local_cookie = "";
@@ -231,7 +216,7 @@ MAIN(int argc, char *argv[], char **envp)
     else if (mode && !strcmp(mode, "register")) {
 	printf("Content-Type: text/plain\n");
 	if (sent_cookie == NULL || Local_cookie[0] == '\0' ||
-	    strcmp(sent_cookie,Local_cookie) != 0) {
+	    strcmp(sent_cookie, Local_cookie) != 0) {
 	    /* local cookie doesn't match: It may be an illegal invocation */
 	    printf("\nBookmark not added: local cookie doesn't match\n");
 	}
